package com.rjconsultores.ventaboletos.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.rjconsultores.ventaboletos.dao.TarifaOficialDAO;
import com.rjconsultores.ventaboletos.entidad.VigenciaTarifa;
import com.rjconsultores.ventaboletos.exception.BusinessException;
import com.rjconsultores.ventaboletos.service.TarifaOficialService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;

@Service("tarifaOficialService")
public class TarifaOficialServiceImpl implements TarifaOficialService {

	@Autowired
	private TarifaOficialDAO tarifaOficialDAO;
	
	@Override
	@Transactional
	public Integer gerarTarifaPorCoeficiente(Integer rutaId, Integer orgaoConcedenteId) {
		return tarifaOficialDAO.gerarTarifaPorCoeficiente(rutaId, UsuarioLogado.getUsuarioLogado().getUsuarioId(), orgaoConcedenteId);
	}

	@Override
	@Transactional
	public Integer atualizarTarifaPorCoeficiente(Integer rutaId, Integer orgaoConcedenteId) {
		return tarifaOficialDAO.atualizarTarifaCoeficiente(rutaId,UsuarioLogado.getUsuarioLogado().getUsuarioId(), orgaoConcedenteId);
	}

	@Override
	@Transactional
	public void copiarParaTarifa(VigenciaTarifa vigenciaTarifa) {
		tarifaOficialDAO.copiarParaTarifa(vigenciaTarifa, UsuarioLogado.getUsuarioLogado().getUsuarioId());
	}

	@Override
	@Transactional
	public Integer gerarAtualizarTarifaPorCoeficiente(Integer rudaId, Integer orgaoConcedenteId) throws BusinessException {
		
		if (orgaoConcedenteId == null){
			throw new BusinessException("TarifaOficialServiceImpl.msg.validacion.orgaoObligatorio");
		}
		
		Integer qtd = gerarTarifaPorCoeficiente(rudaId, orgaoConcedenteId);
		qtd += atualizarTarifaPorCoeficiente(rudaId, orgaoConcedenteId);
		
		return qtd;
	}
	
	@Override
	@Transactional
	public void atualizarTaxaEmbarque(Integer rutaId, Integer orgaoConcedenteId) {
		tarifaOficialDAO.atualizarTaxaEmbarque(rutaId, UsuarioLogado.getUsuarioLogado().getUsuarioId(), orgaoConcedenteId);
	}
	
	@Override
	@Transactional
	public void atualizarSeguroPorKm(Integer rutaId, Integer orgaoId) throws BusinessException {
		
		if (orgaoId == null){
			throw new BusinessException("TarifaOficialServiceImpl.msg.validacion.orgaoObligatorio");
		}
		
		tarifaOficialDAO.atualizarSeguroPorKm(rutaId, orgaoId, UsuarioLogado.getUsuarioLogado().getUsuarioId());
		
	}
	
	@Override
	@Transactional
	public void atualizarSeguroPorTarifa(Integer rutaId, Integer orgaoId) throws BusinessException {
		if (orgaoId == null){
			throw new BusinessException("TarifaOficialServiceImpl.msg.validacion.orgaoObligatorio");
		}
		
		tarifaOficialDAO.atualizarSeguroPorTarifa(rutaId, orgaoId, UsuarioLogado.getUsuarioLogado().getUsuarioId());
	}

	@Override
	@Transactional
	public void atualizarSeguro(Integer rutaId, Integer orgaoId) throws BusinessException {
		if (orgaoId == null){
			throw new BusinessException("TarifaOficialServiceImpl.msg.validacion.orgaoObligatorio");
		}
		
		atualizarSeguroPorKm(rutaId, orgaoId);
		atualizarSeguroPorTarifa(rutaId, orgaoId);
	}

}
